<?php

/**
 * @file
 * BillysBilling module admin settings.
 */

/**
 * Return the BillysBilling global settings form.
 */
function billysbilling_admin_settings() {
  $form['billysbilling_api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('BillysBilling API Key'),
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_api_key', ''),
    '#description' => t('The API key for your BillysBilling account. Get or generate a valid API key at BillysBilling. Please read the !termslink.', array('!termslink' => l(t('BillysBilling API Terms'), 'https://dev.billysbilling.dk/terms'))),
  );

  $form['billysbilling_invoice_message'] = array(
    '#type' => 'textfield',
    '#title' => t('Invoice message'),
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_invoice_message', t('Thanks for shopping with us')),
    '#description' => t('Fixed message for the customer on the invoices.'),
  );

  $client = billysbilling_get_api_object();
  if (!$client instanceof Billy_Client) {
    if ($client == 'no file') {
      drupal_set_message(t('The php-sdk for BillysBilling is required for the BillysBilling module to function. Download the library from !url and place it in <em>!path</em>.', array(
        '!path' => billysbilling_get_library_path(),
        '!url' => l('Github', 'https://github.com/billysbilling/billysbilling-php'))
      ), 'error');
    }
    elseif ($client == 'error') {
      drupal_set_message(t('An error happened while trying to load the Billy client, have you entered a correct API key?'), 'error');
    }
    return system_settings_form($form);
  }
  $response = $client->get("vatModels");

  $options = array(
    '' => t('Choose'),
  );
  foreach ($response->vatModels as $key => $model) {
    $options[$model->id] = $model->name;
  }

  $form['billysbilling_vat_model_id'] = array(
    '#type' => 'select',
    '#title' => t('Default VAT Model'),
    '#options' => $options,
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_vat_model_id', ''),
    '#description' => t('Products will use this VAT model. Create the vat model manually in Billys Billing if not available.'),
  );

  $response = $client->get("accounts");
  $options = array(
    '' => t('Choose'),
  );
  foreach ($response->accounts as $key => $model) {
    $options[$model->id] = $model->name;
  }

  $form['billysbilling_state_account_id'] = array(
    '#type' => 'select',
    '#title' => t('Default State Account'),
    '#options' => $options,
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_state_account_id', ''),
    '#description' => t('Products will be stated on this account. Create the account manually in Billys Billing if not available.'),
  );

  $response = $client->get("products?q=fragt");
  $options = array(
    '' => t('Choose'),
  );
  foreach ($response->products as $key => $model) {
    $options[$model->id] = $model->name;
  }

  $form['billysbilling_shipping_product_id'] = array(
    '#type' => 'select',
    '#title' => t('Shipping product'),
    '#options' => $options,
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_shipping_product_id', ''),
    '#description' => t('Shipping line items will use this product in BillysBilling. Create the product manually in Billys Billing if not available.'),
  );

  $response = $client->get("products?q=rabat");
  $options = array(
    '' => t('Choose'),
  );
  foreach ($response->products as $key => $model) {
    $options[$model->id] = $model->name;
  }

  $form['billysbilling_discount_product_id'] = array(
    '#type' => 'select',
    '#title' => t('Discount product'),
    '#options' => $options,
    '#required' => TRUE,
    '#default_value' => variable_get('billysbilling_discount_product_id', ''),
    '#description' => t('Coupon line items will use this product in BillysBilling. Create the product manually in Billys Billing if not available.'),
  );

  return system_settings_form($form);
}
